﻿using Microsoft.Extensions.Logging;
using PizzeriaContracts.BusinessLogicsContracts;

namespace Pizzeria
{
	public partial class FormMail : Form
	{
		private readonly ILogger _logger;
		private readonly IMessageInfoLogic _logic;

		public FormMail(ILogger<FormMail> logger, IMessageInfoLogic logic)
		{
			InitializeComponent();
			_logger = logger;
			_logic = logic;
		}

		private void LoadData()
		{
			try
			{
				var list = _logic.ReadList(null);
				if (list != null)
				{
					dataGridView.DataSource = list;
					dataGridView.Columns["MessageId"].Visible = false;
					dataGridView.Columns["ClientId"].Visible = false;
					dataGridView.Columns["Body"].AutoSizeMode =
					DataGridViewAutoSizeColumnMode.Fill;
				}
				_logger.LogInformation("Загрузка почтовых собщений");
			}
			catch (Exception ex)
			{
				_logger.LogError(ex, "Ошибка загрузки почтовых сообщений");
				MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
			}
		}

		private void FormMail_Load(object sender, EventArgs e)
		{
			LoadData();
		}
	}
}
