﻿using PizzeriaFileImplement.Models;
using PizzeriaContracts.BindingModels;
using PizzeriaContracts.SearchModels;
using PizzeriaContracts.StorageContracts;
using PizzeriaContracts.ViewModels;

namespace PizzeriaFileImplement.Implements
{
    public class OrderStorage : IOrderStorage
    {
        private readonly DataFileSingleton source;
        public OrderStorage()
        {
            source = DataFileSingleton.GetInstance();
        }

        public OrderViewModel? Delete(OrderBindingModel model)
        {
            var element = source.Orders.FirstOrDefault(x => x.Id == model.Id);
            if (element != null)
            {
                source.Orders.Remove(element);
                source.SaveOrders();
                return AddData(element.GetViewModel);
            }
            return null;
        }
        public OrderViewModel? GetElement(OrderSearchModel model)
        {
            if (!model.Id.HasValue)
            {
                return null;
            }
            var order = source.Orders.FirstOrDefault(x =>
                model.ImplementerId.HasValue && x.ImplementerId == model.ImplementerId && model.Status != null && x.Status.Equals(model.Status)
                || model.Status == null && model.ImplementerId.HasValue && x.ImplementerId == model.ImplementerId
                || model.Id.HasValue && x.Id == model.Id);
            return order?.GetViewModel != null ? AddData(order.GetViewModel) : null;
        }

        public List<OrderViewModel> GetFilteredList(OrderSearchModel model)
        {
            if (model.Id.HasValue)
            {
                return source.Orders.Where(x => x.Id == model.Id).Select(x => AddData(x.GetViewModel)).ToList();
            }
            else if (model.DateFrom.HasValue && model.DateTo.HasValue)
            {
                return source.Orders.Where(x => x.DateCreate >= model.DateFrom && x.DateCreate <= model.DateTo).Select(x => AddData(x.GetViewModel)).ToList();
            }
            else if (model.ClientId.HasValue)
            {
                return source.Orders.Where(x => x.ClientId == model.ClientId).Select(x => AddData(x.GetViewModel)).ToList();
            }
            if (!model.ImplementerId.HasValue && !model.Id.HasValue)
            {
                return source.Orders.Where(x => x.ImplementerId == model.ImplementerId).Select(x => x.GetViewModel).ToList();

            }
            return new();
        }

        public List<OrderViewModel> GetFullList()
        {
            return source.Orders.Select(x => AddData(x.GetViewModel)).ToList();
        }

        public OrderViewModel? Insert(OrderBindingModel model)
        {
            model.Id = source.Orders.Count > 0 ? source.Orders.Max(x => x.Id) + 1 : 1;
            var newOrder = Order.Create(model);
            if (newOrder == null)
            {
                return null;
            }
            source.Orders.Add(newOrder);
            source.SaveOrders();
            return AddData(newOrder.GetViewModel);
        }
        public OrderViewModel? Update(OrderBindingModel model)
        {
            var order = source.Orders.FirstOrDefault(x => x.Id == model.Id);
            if (order == null)
            {
                return null;
            }
            order.Update(model);
            source.SaveOrders();
            return AddData(order.GetViewModel);
        }

        private OrderViewModel AddData(OrderViewModel model)
        {
            var selectedPizza = source.Pizzas.FirstOrDefault(x => x.Id == model.PizzaId);
            model.PizzaName = selectedPizza?.PizzaName;
            var selectedClient = source.Clients.FirstOrDefault(x => x.Id == model.ClientId);
            model.ClientFIO = selectedClient?.ClientFIO ?? string.Empty;
            return model;
        }

    }
}
